@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import sys
 import numpy as np
 from numpy import ma
@@ -46,7 +44,7 @@ def _find_dim(grp, dimname):
             except:
                 raise ValueError("cannot find dimension %s in this group or parent groups" % dimname)
     if dim is None:
-        raise KeyError("dimension %s not defined in group %s or any group in it's family tree" % (dimname, grp.path))
+        raise KeyError("dimension %s not defined in group %s or any group in its family tree" % (dimname, grp.path))
     else:
         return dim
 
@@ -81,7 +79,7 @@ least_significant_digit=1, bits will be 4.
         return datout
 
 def _StartCountStride(elem, shape, dimensions=None, grp=None, datashape=None,\
-        put=False, use_get_vars = False):
+        put=False, use_get_vars = True):
     """Return start, count, stride and indices needed to store/extract data
     into/from a netCDF variable.
 
@@ -428,11 +426,11 @@ Boolean array must have the same shape as the data along this dimension."""
 
         #    ITERABLE    #
         elif np.iterable(e) and np.array(e).dtype.kind in 'i':  # Sequence of integers
-            start[...,i] = np.apply_along_axis(lambda x: e*x, i, np.ones(sdim[:-1]))
-            indices[...,i] = np.apply_along_axis(lambda x: np.arange(sdim[i])*x, i, np.ones(sdim[:-1], int))
-
-            count[...,i] = 1
-            stride[...,i] = 1
+            if start[...,i].size:
+                start[...,i] = np.apply_along_axis(lambda x: e*x, i, np.ones(sdim[:-1]))
+                indices[...,i] = np.apply_along_axis(lambda x: np.arange(sdim[i])*x, i, np.ones(sdim[:-1], int))
+                count[...,i] = 1
+                stride[...,i] = 1
 
         #   all that's left is SCALAR INTEGER    #
         else:
@@ -457,7 +455,7 @@ def _out_array_shape(count):
     out = []
 
     for i, n in enumerate(s):
-        if n == 1:
+        if n == 1 and count.size > 0:
             c = count[..., i].ravel()[0] # All elements should be identical.
             out.append(c)
         else:
@@ -578,7 +576,7 @@ def _nc4tonc3(filename4,filename3,clobber=False,nchunk=10,quiet=False,format='NE
 
     ncfile4 = Dataset(filename4,'r')
     if ncfile4.file_format != 'NETCDF4_CLASSIC':
-        raise IOError('input file must be in NETCDF4_CLASSIC format')
+        raise OSError('input file must be in NETCDF4_CLASSIC format')
     ncfile3 = Dataset(filename3,'w',clobber=clobber,format=format)
     # create dimensions. Check for unlimited dim.
     unlimdimname = False
